==> codeready-workspaces-2.9.0-GA-crwctl-sources.tar.gz: crwctl/lib/commands/workspace/delete.js <==
"use strict";
/*********************************************************************
 * Copyright (c) 2019 Red Hat, Inc.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 **********************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const che_api_client_1 = require("../../api/che-api-client");
const che_login_manager_1 = require("../../api/che-login-manager");
const context_1 = require("../../api/context");
const kube_1 = require("../../api/kube");
const common_flags_1 = require("../../common-flags");
const constants_1 = require("../../constants");
class Delete extends command_1.Command {
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { flags, args } = this.parse(Delete);
            yield context_1.ChectlContext.init(flags, this);
            yield this.config.runHook(constants_1.DEFAULT_ANALYTIC_HOOK_NAME, { command: Delete.id, flags });
            const workspaceId = args.workspace;
            const { cheApiEndpoint, accessToken } = yield che_login_manager_1.getLoginData(flags[common_flags_1.CHE_API_ENDPOINT_KEY], flags[common_flags_1.ACCESS_TOKEN_KEY], flags);
            const cheApiClient = che_api_client_1.CheApiClient.getInstance(cheApiEndpoint);
            yield cheApiClient.deleteWorkspaceById(workspaceId, accessToken);
            cli_ux_1.cli.log(`Workspace with id '${workspaceId}' deleted.`);
            if (flags['delete-namespace']) {
                const workspace = yield cheApiClient.getWorkspaceById(workspaceId, accessToken);
                const infrastructureNamespace = workspace.attributes.infrastructureNamespace;
                if (infrastructureNamespace === flags.chenamespace) {
                    cli_ux_1.cli.warn(`It is not possible to delete namespace '${infrastructureNamespace}' since it is used for CodeReady Workspaces deployment.`);
                    return;
                }
                const kube = new kube_1.KubeHelper(flags);
                if (yield kube.getNamespace(infrastructureNamespace)) {
                    try {
                        yield kube.deleteNamespace(infrastructureNamespace);
                        cli_ux_1.cli.log(`Namespace '${infrastructureNamespace}' deleted.`);
                    }
                    catch (error) {
                        cli_ux_1.cli.warn(`Failed to delete namespace '${infrastructureNamespace}'. Reason: ${error.message}`);
                    }
                }
            }
            this.exit(0);
        });
    }
}
exports.default = Delete;
Delete.description = 'Delete a stopped workspace - use workspace:stop to stop the workspace before deleting it';
Delete.flags = {
    help: command_1.flags.help({ char: 'h' }),
    chenamespace: common_flags_1.cheNamespace,
    'delete-namespace': command_1.flags.boolean({
        description: 'Indicates that a Kubernetes namespace where workspace was created will be deleted as well',
        default: false
    }),
    [common_flags_1.CHE_API_ENDPOINT_KEY]: common_flags_1.cheApiEndpoint,
    [common_flags_1.ACCESS_TOKEN_KEY]: common_flags_1.accessToken,
    'skip-kubernetes-health-check': common_flags_1.skipKubeHealthzCheck,
    telemetry: common_flags_1.CHE_TELEMETRY
};
Delete.args = [
    {
        name: 'workspace',
        description: 'The workspace id to delete',
        required: true
    }
];
//# sourceMappingURL=delete.js.map

==> codeready-workspaces-2.12.1-GA-crwctl-sources.tar.gz: crwctl/lib/commands/workspace/delete.js <==
"use strict";
/**
 * Copyright (c) 2019-2021 Red Hat, Inc.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Red Hat, Inc. - initial API and implementation
 */
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const che_api_client_1 = require("../../api/che-api-client");
const che_login_manager_1 = require("../../api/che-login-manager");
const context_1 = require("../../api/context");
const kube_1 = require("../../api/kube");
const common_flags_1 = require("../../common-flags");
const constants_1 = require("../../constants");
class Delete extends command_1.Command {
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { flags, args } = this.parse(Delete);
            yield context_1.ChectlContext.init(flags, this);
            yield this.config.runHook(constants_1.DEFAULT_ANALYTIC_HOOK_NAME, { command: Delete.id, flags });
            const workspaceId = args.workspace;
            const { cheApiEndpoint, accessToken } = yield che_login_manager_1.getLoginData(flags[common_flags_1.CHE_API_ENDPOINT_KEY], flags[common_flags_1.ACCESS_TOKEN_KEY], flags);
            const cheApiClient = che_api_client_1.CheApiClient.getInstance(cheApiEndpoint);
            yield cheApiClient.deleteWorkspaceById(workspaceId, accessToken);
            cli_ux_1.cli.log(`Workspace with id '${workspaceId}' deleted.`);
            if (flags['delete-namespace']) {
                const workspace = yield cheApiClient.getWorkspaceById(workspaceId, accessToken);
                const infrastructureNamespace = workspace.attributes.infrastructureNamespace;
                if (infrastructureNamespace === flags.chenamespace) {
                    cli_ux_1.cli.warn(`It is not possible to delete namespace '${infrastructureNamespace}' since it is used for CodeReady Workspaces deployment.`);
                    return;
                }
                const kube = new kube_1.KubeHelper(flags);
                if (yield kube.getNamespace(infrastructureNamespace)) {
                    try {
                        yield kube.deleteNamespace(infrastructureNamespace);
                        cli_ux_1.cli.log(`Namespace '${infrastructureNamespace}' deleted.`);
                    }
                    catch (error) {
                        cli_ux_1.cli.warn(`Failed to delete namespace '${infrastructureNamespace}'. Reason: ${error.message}`);
                    }
                }
            }
            this.exit(0);
        });
    }
}
exports.default = Delete;
Delete.description = 'Delete a stopped workspace - use workspace:stop to stop the workspace before deleting it';
Delete.flags = {
    help: command_1.flags.help({ char: 'h' }),
    chenamespace: common_flags_1.cheNamespace,
    'delete-namespace': command_1.flags.boolean({
        description: 'Indicates that a Kubernetes namespace where workspace was created will be deleted as well',
        default: false,
    }),
    [common_flags_1.CHE_API_ENDPOINT_KEY]: common_flags_1.cheApiEndpoint,
    [common_flags_1.ACCESS_TOKEN_KEY]: common_flags_1.accessToken,
    'skip-kubernetes-health-check': common_flags_1.skipKubeHealthzCheck,
    telemetry: common_flags_1.CHE_TELEMETRY,
};
Delete.args = [
    {
        name: 'workspace',
        description: 'The workspace id to delete',
        required: true,
    },
];
//# sourceMappingURL=delete.js.map
